@@ -32,9 +32,9 @@ extern "C" {
 #include <sasl/sasl.h>
 }
 
-#include <qregexp.h>
 #include <QSslSocket>
 #include <QUrlQuery>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 #include <QUrl>
@@ -245,12 +245,12 @@ bool kio_sieveProtocol::parseCapabilities(bool requestCapabilities /* = false*/)
             // Save list of available SASL methods
             const QString val = QLatin1String(r.getVal());
             m_sasl_caps = val.split(QLatin1Char(' '));
-            ksDebug << "Server SASL authentication methods: " << m_sasl_caps.join(QStringLiteral(", ")) << endl;
+            ksDebug << "Server SASL authentication methods: " << m_sasl_caps.join(QLatin1String(", ")) << endl;
             setMetaData(QStringLiteral("saslMethods"), QLatin1String(r.getVal()));
         } else if (r.getKey() == "SIEVE") {
             // Save script capabilities; report back as meta data:
             const QString val = QLatin1String(r.getVal());
-            ksDebug << "Server script capabilities: " << val.split(QLatin1Char(' ')).join(QStringLiteral(", ")) << endl;
+            ksDebug << "Server script capabilities: " << val.split(QLatin1Char(' ')).join(QLatin1String(", ")) << endl;
             setMetaData(QStringLiteral("sieveExtensions"), QLatin1String(r.getVal()));
         } else if (r.getKey() == "STARTTLS") {
             // The server supports TLS
@@ -403,7 +403,7 @@ bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
     infoMessage(i18n("Authenticating user..."));
     if (!authenticate()) {
         disconnect();
-        error(ERR_COULD_NOT_AUTHENTICATE, i18n("Authentication failed."));
+        error(ERR_CANNOT_AUTHENTICATE, i18n("Authentication failed."));
         return false;
     }
 
@@ -566,7 +566,7 @@ void kio_sieveProtocol::put(const QUrl &url, int /*permissions*/, KIO::JobFlags)
         append_lf2crlf(data, buffer);
         if (newSize < 0) {
             // read error: network in unknown state so disconnect
-            error(ERR_COULD_NOT_READ, i18n("KIO data supply error."));
+            error(ERR_CANNOT_READ, i18n("KIO data supply error."));
             return;
         }
         if (newSize == 0) {
@@ -617,7 +617,7 @@ void kio_sieveProtocol::put(const QUrl &url, int /*permissions*/, KIO::JobFlags)
 
     // upload data to the server
     if (write(data.constData(), bufLen) != bufLen) {
-        error(ERR_COULD_NOT_WRITE, i18n("Network error."));
+        error(ERR_CANNOT_WRITE, i18n("Network error."));
         disconnect(true);
         return;
     }
@@ -772,7 +772,7 @@ void kio_sieveProtocol::get(const QUrl &url)
         return;
     }
 
-    infoMessage(i18nc("data retrival complete", "Done."));
+    infoMessage(i18nc("data retrieval complete", "Done."));
     finished();
 }
 
@@ -842,11 +842,11 @@ void kio_sieveProtocol::urlStat(const QUrl &url)
     QString filename = url.fileName();
 
     if (filename.isEmpty()) {
-        entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("/"));
+        entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("/"));
 
-        entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
+        entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
 
-        entry.insert(KIO::UDSEntry::UDS_ACCESS, 0700);
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0700);
 
         statEntry(entry);
     } else {
@@ -864,17 +864,17 @@ void kio_sieveProtocol::urlStat(const QUrl &url)
                 if (filename == QString::fromUtf8(r.getKey())) {
                     entry.clear();
 
-                    entry.insert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
+                    entry.fastInsert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
 
-                    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
+                    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 
                     if (r.getExtra() == "ACTIVE") {
-                        entry.insert(KIO::UDSEntry::UDS_ACCESS, 0700);
+                        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0700);
                     } else {
-                        entry.insert(KIO::UDSEntry::UDS_ACCESS, 0600);
+                        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0600);
                     }
 
-                    entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
+                    entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
 
                     //setMetaData("active", (r.getExtra() == "ACTIVE") ? "yes" : "no");
 
@@ -910,17 +910,17 @@ void kio_sieveProtocol::listDir(const QUrl &url)
             }
         } else {
             entry.clear();
-            entry.insert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
+            entry.fastInsert(KIO::UDSEntry::UDS_NAME, QString::fromUtf8(r.getKey()));
 
-            entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
+            entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG);
 
             if (r.getExtra() == "ACTIVE") {
-                entry.insert(KIO::UDSEntry::UDS_ACCESS, 0700);// mark exec'able
+                entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0700);// mark exec'able
             } else {
-                entry.insert(KIO::UDSEntry::UDS_ACCESS, 0600);
+                entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, 0600);
             }
 
-            entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
+            entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QStringLiteral("application/sieve"));
 
             //asetMetaData("active", (r.getExtra() == "ACTIVE") ? "true" : "false");
 
@@ -943,12 +943,14 @@ bool kio_sieveProtocol::saslInteract(void *in, AuthInfo &ai)
     for (; interact->id != SASL_CB_LIST_END; interact++) {
         if (interact->id == SASL_CB_AUTHNAME
             || interact->id == SASL_CB_PASS) {
-            if (m_sUser.isEmpty() || m_sPass.isEmpty()) {
-                if (!openPasswordDialog(ai)) {
+            if (m_sUser.isEmpty() || m_sPass.isEmpty()) {                
+                const int errorCode = openPasswordDialogV2(ai);
+                if (errorCode) {
                     // calling error() below is wrong for two reasons:
                     // - ERR_ABORTED is too harsh
                     // - higher layers already call error() and that can't happen twice.
                     //error(ERR_ABORTED, i18n("No authentication details supplied."));
+                    error(errorCode, QString());
                     return false;
                 }
                 m_sUser = ai.username;
@@ -983,7 +985,7 @@ bool kio_sieveProtocol::saslInteract(void *in, AuthInfo &ai)
     return true;
 }
 
-#define SASLERROR  error(ERR_COULD_NOT_AUTHENTICATE, i18n("An error occurred during authentication: %1", \
+#define SASLERROR  error(ERR_CANNOT_AUTHENTICATE, i18n("An error occurred during authentication: %1", \
                                                           QString::fromUtf8(sasl_errdetail(conn))));
 
 bool kio_sieveProtocol::authenticate()
@@ -1120,7 +1122,7 @@ bool kio_sieveProtocol::authenticate()
         return true;
     } else {
         // Authentication failed.
-        error(ERR_COULD_NOT_AUTHENTICATE, i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1",
+        error(ERR_CANNOT_AUTHENTICATE, i18n("Authentication failed.\nMost likely the password is wrong.\nThe server responded:\n%1",
                                                QString::fromLatin1(r.getAction())));
         return false;
     }
@@ -1150,7 +1152,7 @@ bool kio_sieveProtocol::sendData(const QByteArray &data)
     // Write the command
     ssize_t write_buf_len = write_buf.length();
     if (write(write_buf.data(), write_buf_len) != write_buf_len) {
-        error(ERR_COULD_NOT_WRITE, i18n("Network error."));
+        error(ERR_CANNOT_WRITE, i18n("Network error."));
         disconnect(true);
         return false;
     }
@@ -1288,12 +1290,13 @@ bool kio_sieveProtocol::requestCapabilitiesAfterStartTLS() const
     // Cyrus didn't send CAPABILITIES after STARTTLS until 2.3.11, which is
     // not standard conform, but we need to support that anyway.
     // m_implementation looks like this 'Cyrus timsieved v2.2.12' for Cyrus btw.
-    QRegExp regExp(QStringLiteral("Cyrus\\stimsieved\\sv(\\d+)\\.(\\d+)\\.(\\d+)([-\\w]*)"), Qt::CaseInsensitive);
-    if (regExp.indexIn(m_implementation) >= 0) {
-        const int major = regExp.cap(1).toInt();
-        const int minor = regExp.cap(2).toInt();
-        const int patch = regExp.cap(3).toInt();
-        const QString vendor = regExp.cap(4);
+    QRegularExpression regExp(QStringLiteral("Cyrus\\stimsieved\\sv(\\d+)\\.(\\d+)\\.(\\d+)([-\\w]*)"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match = regExp.match(m_implementation);
+    if (match.hasMatch()) {
+        const int major = match.captured(1).toInt();
+        const int minor = match.captured(2).toInt();
+        const int patch = match.captured(3).toInt();
+        const QString vendor = match.captured(4);
         if (major < 2 || (major == 2 && (minor < 3 || (minor == 3 && patch < 11))) || (vendor == QLatin1String("-kolab-nocaps"))) {
             ksDebug << " kio_sieveProtocol::requestCapabilitiesAfterStartTLS : Enabling compat mode for Cyrus < 2.3.11 or Cyrus marked as \"kolab-nocaps\"" << endl;
             return true;
