@@ -22,9 +22,11 @@
 
 #include <QObject>
 #include <QUrl>
+#include <memory>
 
 #include <KIO/Global>
-#include <KTcpSocket>
+#include <QSslSocket>
+#include <ksslerroruidata.h>
 
 #include "sasl-common.h"
 #include "response.h"
@@ -52,8 +54,6 @@ public:
 
     void startSsl();
 
-    enum { AuthenticationError = 1500 }; // "extend" KTcpSocket::Error
-
 Q_SIGNALS:
     void responseReceived(const KManageSieve::Response &response, const QByteArray &data);
     void error(int errorCode, const QString &error);
@@ -88,7 +88,7 @@ private:
 private:
     Q_DISABLE_COPY(SessionThread)
     Session *m_session = nullptr;
-    KTcpSocket *m_socket = nullptr;
+    std::unique_ptr<QSslSocket> m_socket;
 
     QUrl m_url;
 
