@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -256,7 +256,7 @@ QString AutoCreateScriptUtil::generateConditionComment(const QString &comment)
                 if (!strComment.isEmpty()) {
                     strComment += QLatin1Char('\n');
                 }
-                strComment += QStringLiteral(" #") + str;
+                strComment += QLatin1String(" #") + str;
             }
         }
     }
