@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,7 +19,6 @@
 
 #include "selectheadersdialogtest.h"
 #include "../sieveconditions/widgets/selectheadertypecombobox.h"
-
 #include <QTest>
 #include <QStandardPaths>
 #include <QDialogButtonBox>
@@ -48,7 +47,7 @@ void SelectHeadersDialogTest::shouldHaveDefaultValue()
 
     QVBoxLayout *lay = dlg.findChild<QVBoxLayout *>(QStringLiteral("widgetlayout"));
     QVERIFY(lay);
-    QCOMPARE(lay->margin(), 0);
+    QCOMPARE(lay->contentsMargins(), QMargins(0, 0, 0, 0));
 
     KSieveUi::SelectHeadersWidget *mListWidget = dlg.findChild<KSieveUi::SelectHeadersWidget *>(QStringLiteral("listwidget"));
     QVERIFY(mListWidget);
