@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -53,10 +53,10 @@ void SelectConvertParameterWidget::setCode(const QStringList &code, QString &err
     }
 
     QString widthStr = code.at(0);
-    widthStr = widthStr.remove(QStringLiteral("pix-x="));
+    widthStr.remove(QStringLiteral("pix-x="));
 
     QString heightStr = code.at(1);
-    heightStr = heightStr.remove(QStringLiteral("pix-y="));
+    heightStr.remove(QStringLiteral("pix-y="));
     mWidth->setValue(widthStr.toInt());
     mHeight->setValue(heightStr.toInt());
 }
@@ -69,7 +69,7 @@ QString SelectConvertParameterWidget::code() const
 void SelectConvertParameterWidget::initialize()
 {
     QBoxLayout *hbox = new QHBoxLayout(this);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     mWidth = new QSpinBox(this);
     mWidth->setSuffix(i18n(" px"));
     mWidth->setMinimum(1);
