@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,21 +22,18 @@
 #include "widgets/moveimapfolderwidget.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include <KLocalizedString>
-#include <QLineEdit>
 
-#include <KPluginLoader>
 #include <QCheckBox>
 #include <QHBoxLayout>
 #include "libksieve_debug.h"
-#include <KPluginFactory>
 #include <QXmlStreamReader>
 //Add support for adding flags
 using namespace KSieveUi;
 SieveActionFileInto::SieveActionFileInto(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveAction(sieveGraphicalModeWidget, QStringLiteral("fileinto"), i18n("File Into"), parent)
 {
-    mHasCopySupport = sieveCapabilities().contains(QStringLiteral("copy"));
-    mHasMailBoxSupport = sieveCapabilities().contains(QStringLiteral("mailbox"));
+    mHasCopySupport = sieveCapabilities().contains(QLatin1String("copy"));
+    mHasMailBoxSupport = sieveCapabilities().contains(QLatin1String("mailbox"));
 }
 
 QString SieveActionFileInto::code(QWidget *w) const
@@ -107,9 +104,8 @@ bool SieveActionFileInto::setParamWidgetValue(QXmlStreamReader &element, QWidget
 QWidget *SieveActionFileInto::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
-    QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
-    w->setLayout(lay);
+    QHBoxLayout *lay = new QHBoxLayout(w);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     if (mHasCopySupport) {
         QCheckBox *copy = new QCheckBox(i18n("Keep a copy"));
@@ -124,15 +120,7 @@ QWidget *SieveActionFileInto::createParamWidget(QWidget *parent) const
         lay->addWidget(create);
     }
 
-    KSieveUi::AbstractMoveImapFolderWidget *edit = nullptr;
-    KPluginLoader loader(QStringLiteral("libksieve/imapfoldercompletionplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        edit = factory->create<KSieveUi::AbstractMoveImapFolderWidget>();
-        edit->setSieveImapAccountSettings(sieveImapAccountSettings());
-    } else {
-        edit = new KSieveUi::MoveImapFolderWidget;
-    }
+    KSieveUi::AbstractMoveImapFolderWidget *edit = AutoCreateScriptUtil::createImapFolderWidget();
     connect(edit, &KSieveUi::AbstractMoveImapFolderWidget::textChanged, this, &SieveActionFileInto::valueChanged);
     lay->addWidget(edit);
     edit->setObjectName(QStringLiteral("fileintolineedit"));
