@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,9 +26,9 @@ class SieveActionSetFlags : public SieveActionAbstractFlags
     Q_OBJECT
 public:
     explicit SieveActionSetFlags(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString flagsCode() const override;
-    QString help() const override;
-    QUrl href() const override;
+    Q_REQUIRED_RESULT QString flagsCode() const override;
+    Q_REQUIRED_RESULT QString help() const override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
 
