@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,14 +25,15 @@
 #include "sieveactions/sieveactionlist.h"
 #include "commonwidgets/sievehelpbutton.h"
 #include "autocreatescriptutil_p.h"
-#include <PimCommon/MinimumComboBox>
 
 #include <QPushButton>
 #include <KLocalizedString>
 #include <QIcon>
 
+#include <QComboBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QPointer>
 #include "libksieve_debug.h"
 #include <QToolButton>
 #include <QWhatsThis>
@@ -114,11 +115,12 @@ void SieveActionWidget::initWidget()
     mLayout = new QGridLayout(this);
     mLayout->setContentsMargins(0, 0, 0, 0);
 
-    mComboBox = new PimCommon::MinimumComboBox;
+    mComboBox = new QComboBox;
     mComboBox->setEditable(false);
-    const QList<KSieveUi::SieveAction *> list = KSieveUi::SieveActionList::actionList(mSieveGraphicalModeWidget);
-    QList<KSieveUi::SieveAction *>::const_iterator it;
-    QList<KSieveUi::SieveAction *>::const_iterator end(list.constEnd());
+    mComboBox->setMinimumWidth(50);
+    const QVector<KSieveUi::SieveAction *> list = KSieveUi::SieveActionList::actionList(mSieveGraphicalModeWidget);
+    QVector<KSieveUi::SieveAction *>::const_iterator it;
+    QVector<KSieveUi::SieveAction *>::const_iterator end(list.constEnd());
     int index = 0;
     QStringList listCapabilities = mSieveGraphicalModeWidget->sieveCapabilities();
     //imapflags was old name of imap4flags but still used.
@@ -165,7 +167,7 @@ void SieveActionWidget::initWidget()
 
     updateGeometry();
 
-    connect(mComboBox, QOverload<int>::of(&PimCommon::MinimumComboBox::activated), this, &SieveActionWidget::slotActionChanged);
+    connect(mComboBox, QOverload<int>::of(&QComboBox::activated), this, &SieveActionWidget::slotActionChanged);
 
     mAdd = new QPushButton(this);
     mAdd->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
@@ -412,7 +414,7 @@ void SieveActionWidgetLister::loadScript(QXmlStreamReader &element, bool onlyAct
                 qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript don't have name attribute " << tagName;
             }
         } else {
-            qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript Unknow tag name " << tagName;
+            qCDebug(LIBKSIEVE_LOG) << " SieveActionWidgetLister::loadScript Unknown tag name " << tagName;
         }
     } else {
         bool firstAction = true;
