@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -36,14 +36,14 @@ using namespace KSieveUi;
 SieveConditionSpamTest::SieveConditionSpamTest(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
     : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("spamtest"), i18n("Spam Test"), parent)
 {
-    mHasSpamTestPlusSupport = sieveCapabilities().contains(QStringLiteral("spamtestplus"));
+    mHasSpamTestPlusSupport = sieveCapabilities().contains(QLatin1String("spamtestplus"));
 }
 
 QWidget *SieveConditionSpamTest::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QVBoxLayout *lay = new QVBoxLayout;
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
 
     if (mHasSpamTestPlusSupport) {
