@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,7 +32,7 @@ public:
     explicit SelectBodyTypeWidget(QWidget *parent = nullptr);
     ~SelectBodyTypeWidget();
 
-    QString code() const;
+    Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &type, const QString &content, const QString &name, QString &error);
 
 Q_SIGNALS:
