@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,10 +28,10 @@ public:
     explicit SelectMimeComboBox(QWidget *parent = nullptr);
     ~SelectMimeComboBox();
 
-    QString code() const;
+    Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &code, const QString &name, QString &error);
 
-    QString require() const;
+    Q_REQUIRED_RESULT QString require() const;
 
 Q_SIGNALS:
     void valueChanged();
