@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -109,7 +109,7 @@ QString SieveDateSpinBox::convertValue() const
         str = QStringLiteral("%1").arg(value(), 2, 10, QLatin1Char('0'));
         break;
     case SelectDateWidget::Weekday:
-        str = QStringLiteral("%1").arg(value());
+        str = value();
         break;
     default:
         qCWarning(LIBKSIEVE_LOG) << "This type mustn't be selected " << mType;
