@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,10 +26,7 @@ class QPushButton;
 class QGridLayout;
 class QXmlStreamReader;
 class QToolButton;
-
-namespace PimCommon {
-class MinimumComboBox;
-}
+class QComboBox;
 
 namespace KSieveUi {
 class SieveCondition;
@@ -63,7 +60,7 @@ private:
     QList<KSieveUi::SieveCondition *> mConditionList;
     QPushButton *mAdd = nullptr;
     QPushButton *mRemove = nullptr;
-    PimCommon::MinimumComboBox *mComboBox = nullptr;
+    QComboBox *mComboBox = nullptr;
     QGridLayout *mLayout = nullptr;
     SieveHelpButton *mHelpButton = nullptr;
     QToolButton *mCommentButton = nullptr;
@@ -77,7 +74,7 @@ public:
     explicit SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
     ~SieveConditionWidgetLister();
 
-    void generatedScript(QString &script, int &numberOfCondition, QStringList &requires, bool inForEveryPartLoop);
+    void generatedScript(QString &script, int &numberOfCondition, QStringList &requireModules, bool inForEveryPartLoop);
     int conditionNumber() const;
     void loadScript(QXmlStreamReader &element, bool uniqTest, bool notCondition, QString &error);
 
