@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -40,7 +40,7 @@ SieveEditorGraphicalModeWidget::SieveEditorGraphicalModeWidget(QWidget *parent)
     : SieveEditorGraphicalModeWidgetAbstract::SieveEditorGraphicalModeWidgetAbstract(parent)
 {
     QVBoxLayout *vlay = new QVBoxLayout(this);
-    vlay->setMargin(0);
+    vlay->setContentsMargins(0, 0, 0, 0);
 
     mSplitter = new QSplitter;
     mSplitter->setChildrenCollapsible(false);
@@ -126,10 +126,10 @@ void SieveEditorGraphicalModeWidget::slotActivateScriptPage(QWidget *page)
 
 QString SieveEditorGraphicalModeWidget::currentscript()
 {
-    QString requires;
-    QString script = mSieveScript->generatedScript(requires);
-    if (!requires.isEmpty()) {
-        script.prepend(requires + QLatin1Char('\n'));
+    QString requireModules;
+    QString script = mSieveScript->generatedScript(requireModules);
+    if (!requireModules.isEmpty()) {
+        script.prepend(requireModules + QLatin1Char('\n'));
     }
     return script;
 }
