@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,6 @@
 #include <KLocalizedString>
 #include <QInputDialog>
 #include <QPushButton>
-#include <KIconLoader>
 #include <QIcon>
 
 #include <QVBoxLayout>
@@ -49,7 +48,6 @@ using namespace KSieveUi;
 
 SieveScriptListItem::SieveScriptListItem(const QString &text, QListWidget *parent)
     : QListWidgetItem(text, parent)
-    , mScriptPage(nullptr)
 {
 }
 
@@ -77,7 +75,7 @@ void SieveScriptListItem::setScriptPage(SieveScriptPage *page)
     mScriptPage = page;
 }
 
-QString SieveScriptListItem::generatedScript(QStringList &requires) const
+QString SieveScriptListItem::generatedScript(QStringList &required) const
 {
     QString script;
     if (!mDescription.trimmed().isEmpty()) {
@@ -91,7 +89,7 @@ QString SieveScriptListItem::generatedScript(QStringList &requires) const
         }
     }
     if (mScriptPage) {
-        mScriptPage->generatedScript(script, requires);
+        mScriptPage->generatedScript(script, required);
     }
     return script;
 }
@@ -106,32 +104,28 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     //----------- the first row of buttons
     QWidget *hb = new QWidget(this);
     QHBoxLayout *hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hbHBoxLayout->setSpacing(4);
 
     mBtnTop = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnTop);
     mBtnTop->setIcon(QIcon::fromTheme(QStringLiteral("go-top")));
-    mBtnTop->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnTop->setMinimumSize(mBtnTop->sizeHint() * 1.2);
 
     mBtnUp = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnUp);
     mBtnUp->setAutoRepeat(true);
     mBtnUp->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-    mBtnUp->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnUp->setMinimumSize(mBtnUp->sizeHint() * 1.2);
     mBtnDown = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnDown);
     mBtnDown->setAutoRepeat(true);
     mBtnDown->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    mBtnDown->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnDown->setMinimumSize(mBtnDown->sizeHint() * 1.2);
 
     mBtnBottom = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnBottom);
     mBtnBottom->setIcon(QIcon::fromTheme(QStringLiteral("go-bottom")));
-    mBtnBottom->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnBottom->setMinimumSize(mBtnBottom->sizeHint() * 1.2);
 
     mBtnUp->setToolTip(i18nc("Move selected filter up.", "Up"));
@@ -143,34 +137,30 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
 
     hb = new QWidget(this);
     hbHBoxLayout = new QHBoxLayout(hb);
-    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setContentsMargins(0, 0, 0, 0);
     hbHBoxLayout->setSpacing(4);
 
     mBtnNew = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnNew);
     mBtnNew->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
-    mBtnNew->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnNew->setToolTip(i18n("New Script"));
     mBtnNew->setMinimumSize(mBtnNew->sizeHint() * 1.2);
 
     mBtnDelete = new QPushButton(hb);
     hbHBoxLayout->addWidget(mBtnDelete);
     mBtnDelete->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-    mBtnDelete->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnDelete->setToolTip(i18n("Delete Script"));
     mBtnDelete->setMinimumSize(mBtnDelete->sizeHint() * 1.2);
 
     mBtnRename = new QPushButton(hb);
     mBtnRename->setToolTip(i18n("Rename Script"));
     mBtnRename->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
-    mBtnRename->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnRename->setMinimumSize(mBtnRename->sizeHint() * 1.2);
     hbHBoxLayout->addWidget(mBtnRename);
 
     mBtnDescription = new QPushButton(hb);
     mBtnDescription->setToolTip(i18n("Edit Script Description"));
     mBtnDescription->setIcon(QIcon::fromTheme(QStringLiteral("edit-comment")));
-    mBtnDescription->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mBtnDescription->setMinimumSize(mBtnDescription->sizeHint() * 1.2);
 
     hbHBoxLayout->addWidget(mBtnDescription);
@@ -349,7 +339,7 @@ void SieveScriptListBox::slotUp()
     }
 }
 
-QString SieveScriptListBox::generatedScript(QString &requires) const
+QString SieveScriptListBox::generatedScript(QString &requireModules) const
 {
     QString resultScript;
     QStringList lstRequires;
@@ -370,7 +360,7 @@ QString SieveScriptListBox::generatedScript(QString &requires) const
     for (const QString &r : qAsConst(lstRequires)) {
         if (!endRequires.contains(r)) {
             endRequires.append(r);
-            requires += QStringLiteral("require \"%1\";\n").arg(r);
+            requireModules += QStringLiteral("require \"%1\";\n").arg(r);
         }
     }
 
@@ -414,8 +404,8 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             if (typeBlock == TypeBlockAction) {
                 currentPage = nullptr;
             }
-            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
-                const QString controlType = n.attributes().value(QStringLiteral("name")).toString();
+            if (n.attributes().hasAttribute(QLatin1String("name"))) {
+                const QString controlType = n.attributes().value(QLatin1String("name")).toString();
                 //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
                 if (controlType == QLatin1String("if")) {
                     typeBlock = TypeBlockIf;
@@ -491,8 +481,8 @@ void SieveScriptListBox::loadBlock(QXmlStreamReader &n, SieveScriptPage *current
             //qDebug() << " COMMENT " << comment;
         } else if (tagName == QLatin1String("action")) {
             previousElementWasAComment = false;
-            if (n.attributes().hasAttribute(QStringLiteral("name"))) {
-                const QString actionName = n.attributes().value(QStringLiteral("name")).toString();
+            if (n.attributes().hasAttribute(QLatin1String("name"))) {
+                const QString actionName = n.attributes().value(QLatin1String("name")).toString();
                 if (actionName == QLatin1String("include")) {
                     if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
                         currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
