@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,12 +16,12 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#include <qdebug.h>
+#include <QDebug>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 #include "../autocreatescriptdialog.h"
-#include <PimCommon/SieveSyntaxHighlighterUtil>
+#include "tests/capability.h"
 
 int main(int argc, char **argv)
 {
@@ -33,14 +33,13 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
     KSieveUi::AutoCreateScriptDialog *dialog = new KSieveUi::AutoCreateScriptDialog;
-    PimCommon::SieveSyntaxHighlighterUtil sieveHighlighterutil;
-    const QStringList capabilities = sieveHighlighterutil.fullCapabilities();
+    const QStringList capabilities = KSieveUi::Test::fullCapabilitiesList();
     //Add all capabilities for testing
     dialog->setSieveCapabilities(capabilities);
     if (dialog->exec()) {
-        QString requires;
-        const QString script = dialog->script(requires);
-        qDebug() << " generated script :\n" << requires << "\n" << script;
+        QString requireModules;
+        const QString script = dialog->script(requireModules);
+        qDebug() << " generated script :\n" << requireModules << "\n" << script;
     }
     delete dialog;
     return 0;
