@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "sievetextedittest.h"
 #include "../sievetextedit.h"
-#include <qtest.h>
+#include <QTest>
 
 SieveTextEditTest::SieveTextEditTest(QObject *parent)
     : QObject(parent)
