@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,6 +18,7 @@
 #include "sieveeditormenubar.h"
 #include "sieveeditortextmodewidget.h"
 #include "sieveeditortabwidget.h"
+
 #include <KStandardAction>
 #include <KLocalizedString>
 #include <QAction>
@@ -26,7 +27,6 @@ using namespace KSieveUi;
 
 SieveEditorMenuBar::SieveEditorMenuBar(QWidget *parent)
     : QMenuBar(parent)
-    , mTextModeWidget(nullptr)
 {
     initActions();
     initMenus();
@@ -90,10 +90,7 @@ void SieveEditorMenuBar::initActions()
     mPrintAction = KStandardAction::print(this, &SieveEditorMenuBar::print, this);
     mPrintPreviewAction = KStandardAction::printPreview(this, &SieveEditorMenuBar::printPreview, this);
 
-    mZoomResetAction = new QAction(i18nc("Reset the zoom", "Reset"), this);
-    mZoomResetAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_0));
-    connect(mZoomResetAction, &QAction::triggered, this, &SieveEditorMenuBar::zoomReset);
-
+    mZoomResetAction = KStandardAction::actualSize(this, &SieveEditorMenuBar::zoomReset, this);
     mWordWrapAction = new QAction(i18n("Wordwrap"), this);
     mWordWrapAction->setCheckable(true);
     connect(mWordWrapAction, &QAction::triggered, this, &SieveEditorMenuBar::wordWrap);
@@ -115,7 +112,6 @@ void SieveEditorMenuBar::initMenus()
     mFileMenu->addAction(mPrintAction);
     mFileMenu->addAction(mPrintPreviewAction);
     mEditorMenu = addMenu(i18nc("@title:menu", "Edit"));
-    mToolsMenu = addMenu(i18nc("@title:menu", "Tools"));
     mEditorMenu->addAction(mUndoAction);
     mEditorMenu->addAction(mRedoAction);
     mEditorMenu->addSeparator();
@@ -130,15 +126,18 @@ void SieveEditorMenuBar::initMenus()
     mEditorMenu->addSeparator();
     mEditorMenu->addAction(mGoToLine);
     mEditorMenu->addSeparator();
-    mEditorMenu->addAction(mZoomInAction);
-    mEditorMenu->addAction(mZoomOutAction);
-    mEditorMenu->addAction(mZoomResetAction);
-    mEditorMenu->addSeparator();
     mEditorMenu->addAction(mWordWrapAction);
+    mEditorMenu->addSeparator();
+    mEditorMenu->addAction(mCommentCodeAction);
+    mEditorMenu->addAction(mUncommentCodeAction);
 
-    mToolsMenu->addAction(mCommentCodeAction);
-    mToolsMenu->addAction(mUncommentCodeAction);
-    mToolsMenu->addSeparator();
+    mViewMenu = addMenu(i18nc("@title:menu", "View"));
+    mViewMenu->addAction(mZoomInAction);
+    mViewMenu->addAction(mZoomOutAction);
+    mViewMenu->addSeparator();
+    mViewMenu->addAction(mZoomResetAction);
+
+    mToolsMenu = addMenu(i18nc("@title:menu", "Tools"));
     mToolsMenu->addAction(mDebugSieveAction);
 }
 
@@ -171,6 +170,11 @@ void SieveEditorMenuBar::slotUpdateActions()
     mPrintPreviewAction->setEnabled(!hasActionInHtmlModeToo);
 }
 
+QMenu *SieveEditorMenuBar::viewMenu() const
+{
+    return mViewMenu;
+}
+
 void SieveEditorMenuBar::setTextModeWidget(SieveEditorTextModeWidget *textModeWidget)
 {
     if (!mTextModeWidget) {
