@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -19,6 +19,7 @@
 */
 
 #include "sieveeditorwidget.h"
+#include "sievepurposemenuwidget.h"
 
 #include "sieve-editor.h"
 #include "sieveeditortextmodewidget.h"
@@ -34,7 +35,8 @@
 #include <kzip.h>
 #include <KIconEngine>
 #include <KStandardAction>
-#include <QTemporaryFile>
+
+#include <PimCommon/PurposeMenuWidget>
 
 #include <QPushButton>
 #include <QVBoxLayout>
@@ -46,6 +48,7 @@
 #include <QAction>
 #include <QPointer>
 #include <QDir>
+#include <QTemporaryFile>
 
 using namespace KSieveUi;
 
@@ -81,11 +84,19 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
 
     QStringList overlays;
     overlays << QStringLiteral("list-add");
-    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share..."), this);
+    mShareScript = new QAction(QIcon(new KIconEngine(QStringLiteral("get-hot-new-stuff"), KIconLoader::global(), overlays)), i18n("Share Script..."), this);
     connect(mShareScript, &QAction::triggered, this, &SieveEditorWidget::slotShareScript);
     //Add action to toolBar
 
     toolbar->addAction(mShareScript);
+
+    SievePurposeMenuWidget *purposeMenu = new SievePurposeMenuWidget(this, this);
+    QAction *shareAction = new QAction(i18n("Share..."), this);
+    shareAction->setMenu(purposeMenu->menu());
+    shareAction->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    purposeMenu->setEditorWidget(this);
+    toolbar->addAction(shareAction);
+
     SieveEditorMenuBar *menuBar = nullptr;
     if (useMenuBar) {
         menuBar = new SieveEditorMenuBar;
@@ -117,6 +128,8 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
         menuBar->fileMenu()->addSeparator();
         menuBar->fileMenu()->addAction(mShareScript);
         menuBar->toolsMenu()->addSeparator();
+        menuBar->fileMenu()->addAction(shareAction);
+        menuBar->toolsMenu()->addSeparator();
         menuBar->toolsMenu()->addAction(mCreateRulesGraphically);
         menuBar->toolsMenu()->addAction(mCheckSyntax);
         lay->addWidget(menuBar);
@@ -132,12 +145,12 @@ SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     nameLayout->addWidget(mScriptName);
     lay->addLayout(nameLayout);
 
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     mStackedWidget = new QStackedWidget;
 
     mTextModeWidget = new SieveEditorTextModeWidget;
     connect(mTextModeWidget, &SieveEditorTextModeWidget::valueChanged, this, &SieveEditorWidget::slotModified);
-    if (useMenuBar) {
+    if (menuBar) {
         menuBar->setTextModeWidget(mTextModeWidget);
     }
     mStackedWidget->addWidget(mTextModeWidget);
@@ -466,7 +479,8 @@ QString SieveEditorWidget::originalScript() const
 void SieveEditorWidget::setScript(const QString &script, bool clearUndoRedo)
 {
     mTextModeWidget->setScript(script, clearUndoRedo);
-    mOriginalScript = script;
+    //Necessary to take text from editor otherwise script has \r\n
+    mOriginalScript = mTextModeWidget->script();
 }
 
 void SieveEditorWidget::addFailedMessage(const QString &err)
