@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,7 @@
 #include "ksieveui/editor/sieveeditor.h"
 #include "ksieveui/tests/capability.h"
 
-#include <qapplication.h>
+#include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
