@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,7 @@ class SieveEditorWebEngineView : public QWebEngineView
     Q_OBJECT
 public:
     explicit SieveEditorWebEngineView(QWidget *parent = nullptr);
-    ~SieveEditorWebEngineView();
+    ~SieveEditorWebEngineView() override;
 
 protected:
     void contextMenuEvent(QContextMenuEvent *ev) override;
