@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -37,6 +37,7 @@ public:
     ~ParseUserScriptJob();
 
     void start();
+    void setAutoDelete(bool deleteMe);
 
     Q_REQUIRED_RESULT QUrl scriptUrl() const;
 
@@ -57,9 +58,10 @@ private:
     QStringList extractActiveScript(const QString &doc);
     QUrl mCurrentUrl;
     KManageSieve::SieveJob *mSieveJob = nullptr;
+    QXmlStreamReader *mStreamReader = nullptr;
     QStringList mActiveScripts;
     QString mError;
-    QXmlStreamReader *mStreamReader = nullptr;
+    bool mAutoDelete = false;
 };
 }
 
