@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,6 @@
 #include "vacationmailactionwidgettest.h"
 #include "../vacationmailactionwidget.h"
 #include <QHBoxLayout>
-#include <QLineEdit>
 #include <QStackedWidget>
 #include <QTest>
 #include <KSieveUi/AbstractMoveImapFolderWidget>
@@ -39,7 +38,7 @@ void VacationMailActionWidgetTest::shouldHaveDefaultValue()
 
     QHBoxLayout *mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->margin(), 0);
+    QCOMPARE(mainLayout->contentsMargins(), QMargins(0, 0, 0, 0));
 
     QStackedWidget *mStackedWidget = w.findChild<QStackedWidget *>(QStringLiteral("stackedWidget"));
     QVERIFY(mStackedWidget);
@@ -65,7 +64,8 @@ void VacationMailActionWidgetTest::shouldHaveDefaultValue()
     QVERIFY(abstractSelectEmailWidget);
     QCOMPARE(abstractSelectEmailWidget->objectName(), QStringLiteral("selectEmailLineEdit"));
 
-    QVERIFY(w.mailActionRecipient().isEmpty());
+    bool ok;
+    QVERIFY(w.mailActionRecipient(ok).isEmpty());
 }
 
 void VacationMailActionWidgetTest::shouldSwitchComponents()
@@ -75,21 +75,22 @@ void VacationMailActionWidgetTest::shouldSwitchComponents()
 
     w.mailActionChanged(KSieveUi::VacationUtils::Keep);
     QCOMPARE(mStackedWidget->currentIndex(), 0);
-    QVERIFY(w.mailActionRecipient().isEmpty());
+    bool ok;
+    QVERIFY(w.mailActionRecipient(ok).isEmpty());
     QVERIFY(!w.isEnabled());
 
     w.mailActionChanged(KSieveUi::VacationUtils::CopyTo);
     QCOMPARE(mStackedWidget->currentIndex(), 1);
-    QVERIFY(w.mailActionRecipient().isEmpty());
+    QVERIFY(w.mailActionRecipient(ok).isEmpty());
     QVERIFY(w.isEnabled());
 
     w.mailActionChanged(KSieveUi::VacationUtils::Discard);
     QCOMPARE(mStackedWidget->currentIndex(), 0);
-    QVERIFY(w.mailActionRecipient().isEmpty());
+    QVERIFY(w.mailActionRecipient(ok).isEmpty());
     QVERIFY(!w.isEnabled());
 
     w.mailActionChanged(KSieveUi::VacationUtils::Sendto);
     QCOMPARE(mStackedWidget->currentIndex(), 2);
-    QVERIFY(w.mailActionRecipient().isEmpty());
+    QVERIFY(w.mailActionRecipient(ok).isEmpty());
     QVERIFY(w.isEnabled());
 }
