@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,6 +31,10 @@ namespace KSieveUi {
 class CheckKolabKep14SupportJob;
 class VacationCheckJob;
 class SieveImapPasswordProvider;
+/**
+ * @brief The MultiImapVacationManager class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KSIEVEUI_EXPORT MultiImapVacationManager : public QObject
 {
     Q_OBJECT
@@ -52,6 +56,7 @@ private Q_SLOTS:
     void slotCheckKep14Ended(KSieveUi::CheckKolabKep14SupportJob *job, bool success);
 
 private:
+    Q_DISABLE_COPY(MultiImapVacationManager)
     SieveImapPasswordProvider *mPasswordProvider = nullptr;
     int mNumberOfJobs = 0;
     bool mCheckInProgress = false;
