@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -43,7 +43,7 @@ public:
     QString serverName() const;
 
 Q_SIGNALS:
-    void scriptActive(VacationCheckJob *job, const QString &sscriptName, bool active);
+    void vacationScriptActive(VacationCheckJob *job, const QString &sscriptName, bool active);
     void error(const QString &errorStr);
 
 private Q_SLOTS:
@@ -56,6 +56,7 @@ private Q_SLOTS:
     bool isLastScript() const;
 
 private:
+    Q_DISABLE_COPY(VacationCheckJob)
     QStringList mAvailableScripts;
     QStringList mActiveScripts;
     QStringList mSieveCapabilities;
