@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,15 +29,6 @@ using namespace KSieveUi;
 
 VacationCreateScriptJob::VacationCreateScriptJob(QObject *parent)
     : QObject(parent)
-    , mActivate(false)
-    , mScriptActive(false)
-    , mKep14Support(false)
-    , mUserJobRunning(false)
-    , mScriptJobRunning(false)
-    , mSuccess(true)
-    , mSieveJob(nullptr)
-    , mParseUserJob(nullptr)
-    , mCreateJob(nullptr)
 {
 }
 
