@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -44,6 +44,7 @@ public:
     void setVacationManager(MultiImapVacationManager *vacationManager);
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
 
+    bool wasChanged() const;
 private Q_SLOTS:
     void slotGetResult(const QString &serverName, const QStringList &sieveCapabilities, const QString &scriptName, const QString &script, bool active);
 
@@ -62,7 +63,7 @@ private:
     VacationEditWidget *mVacationEditWidget = nullptr;
     VacationWarningWidget *mVacationWarningWidget = nullptr;
     MultiImapVacationManager *mVacationManager = nullptr;
-    PageType mPageScript;
+    PageType mPageScript = Script;
     bool mWasActive = false;
     bool mHasDateSupport = false;
 };
