@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -408,40 +408,40 @@ private:
 
 typedef GenericInformationExtractor GIE;
 static const GenericInformationExtractor::StateNode spamNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, 0 },               // 0
-    { 0, GIE::TestStart, "allof", 2, 3, 0 },               // 1
-    { 0, GIE::TestListStart, 0, 3, 0, 0 },                 // 2
-    { 0, GIE::TestStart, "not", 4, 3, 0 },                 // 3
-    { 0, GIE::TestStart, "header", 5, 3, 0 },              // 4
-    { 0, GIE::TaggedArgument, "contains", 6, 0, 0 },       // 5
+    { 0, GIE::CommandStart, "if", 1, 0, nullptr },               // 0
+    { 0, GIE::TestStart, "allof", 2, 3, nullptr },               // 1
+    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },                 // 2
+    { 0, GIE::TestStart, "not", 4, 3, nullptr },                 // 3
+    { 0, GIE::TestStart, "header", 5, 3, nullptr },              // 4
+    { 0, GIE::TaggedArgument, "contains", 6, 0, nullptr },       // 5
 
     // accept both string and string-list:
     { 0, GIE::StringArgument, "x-spam-flag", 12, 7, "x-spam-flag" },        // 6
-    { 0, GIE::StringListArgumentStart, 0, 8, 0, 0 },                       // 7
+    { 0, GIE::StringListArgumentStart, nullptr, 8, 0, nullptr },                       // 7
     { 0, GIE::StringListEntry, "x-spam-flag", 9, 10, "x-spam-flag" },       // 8
-    { 0, GIE::StringListEntry, 0, 9, 11, 0 },                               // 9
-    { 0, GIE::StringListArgumentEnd, 0, 0, 8, 0 },                         // 10
-    { 0, GIE::StringListArgumentEnd, 0, 12, 0, 0 },                         // 11
+    { 0, GIE::StringListEntry, nullptr, 9, 11, nullptr },                               // 9
+    { 0, GIE::StringListArgumentEnd, nullptr, 0, 8, nullptr },                         // 10
+    { 0, GIE::StringListArgumentEnd, nullptr, 12, 0, nullptr },                         // 11
 
     // accept both string and string-list:
     { 0, GIE::StringArgument, "yes", 18, 13, "spam-flag-yes" },        // 12
-    { 0, GIE::StringListArgumentStart, 0, 14, 0, 0 },                  // 13
+    { 0, GIE::StringListArgumentStart, nullptr, 14, 0, nullptr },                  // 13
     { 0, GIE::StringListEntry, "yes", 15, 16, "spam-flag-yes" },       // 14
-    { 0, GIE::StringListEntry, 0, 15, 17, 0 },                         // 15
-    { 0, GIE::StringListArgumentEnd, 0, 0, 14, 0 },                    // 16
-    { 0, GIE::StringListArgumentEnd, 0, 18, 0, 0 },                    // 17
+    { 0, GIE::StringListEntry, nullptr, 15, 17, nullptr },                         // 15
+    { 0, GIE::StringListArgumentEnd, nullptr, 0, 14, nullptr },                    // 16
+    { 0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr },                    // 17
 
-    { 0, GIE::TestEnd, 0, 21, 20, 0 },       // 18
-    { 0, GIE::Any, 0, 21, 0, 0 },            // 19
-    { 0, GIE::TestListEnd, 0, 21, 19, 0 },   // 20
+    { 0, GIE::TestEnd, nullptr, 21, 20, nullptr },       // 18
+    { 0, GIE::Any, nullptr, 21, 0, nullptr },            // 19
+    { 0, GIE::TestListEnd, nullptr, 21, 19, nullptr },   // 20
 
     // block of command, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, 0, 22, 18, 0 },                         // 21
+    { 0, GIE::BlockStart, nullptr, 22, 18, nullptr },                         // 21
     { 1, GIE::CommandStart, "vacation", 24, 22, "vacation" },     // 22
-    { 1, GIE::Any, 0, 24, 0, 0 },                                 // 23
-    { 0, GIE::BlockEnd, 0, 25, 23, 0 },                           // 24
+    { 1, GIE::Any, nullptr, 24, 0, nullptr },                                 // 23
+    { 0, GIE::BlockEnd, nullptr, 25, 23, nullptr },                           // 24
 
-    { -1, GIE::Any, 0, 25, 25, 0 },   // 25 end state
+    { -1, GIE::Any, nullptr, 25, 25, nullptr },   // 25 end state
 };
 static const unsigned int numSpamNodes = sizeof spamNodes / sizeof *spamNodes;
 
@@ -465,41 +465,41 @@ public:
 // libksieve/tests/parsertest
 //   'if not address :domain :contains ["from"] ["mydomain.org"] { keep; stop; }'
 static const GenericInformationExtractor::StateNode domainNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, 0 },       // 0
-    { 0, GIE::TestStart, "allof", 2, 3, 0 },       // 1
-    { 0, GIE::TestListStart, 0, 3, 0, 0 },         // 2
-    { 0, GIE::TestStart, "address", 4, 3, 0 },     // 3
+    { 0, GIE::CommandStart, "if", 1, 0, nullptr },       // 0
+    { 0, GIE::TestStart, "allof", 2, 3, nullptr },       // 1
+    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },         // 2
+    { 0, GIE::TestStart, "address", 4, 3, nullptr },     // 3
 
     // :domain and :contains in arbitrary order:
-    { 0, GIE::TaggedArgument, "domain", 5, 6, 0 },           // 4
-    { 0, GIE::TaggedArgument, "contains", 8, 0, 0 },         // 5
-    { 0, GIE::TaggedArgument, "contains", 7, 0, 0 },         // 6
-    { 0, GIE::TaggedArgument, "domain", 8, 0, 0 },           // 7
+    { 0, GIE::TaggedArgument, "domain", 5, 6, nullptr },           // 4
+    { 0, GIE::TaggedArgument, "contains", 8, 0, nullptr },         // 5
+    { 0, GIE::TaggedArgument, "contains", 7, 0, nullptr },         // 6
+    { 0, GIE::TaggedArgument, "domain", 8, 0, nullptr },           // 7
 
     // accept both string and string-list:
     { 0, GIE::StringArgument, "from", 14, 9, "from" },           // 8
-    { 0, GIE::StringListArgumentStart, 0, 10, 0, 0 },             // 9
+    { 0, GIE::StringListArgumentStart, nullptr, 10, 0, nullptr },             // 9
     { 0, GIE::StringListEntry, "from", 11, 12, "from" },         // 10
-    { 0, GIE::StringListEntry, 0, 11, 13, 0 },                   // 11
-    { 0, GIE::StringListArgumentEnd, 0, 0, 10, 0 },               // 12
-    { 0, GIE::StringListArgumentEnd, 0, 14, 0, 0 },              // 13
+    { 0, GIE::StringListEntry, nullptr, 11, 13, nullptr },                   // 11
+    { 0, GIE::StringListArgumentEnd, nullptr, 0, 10, nullptr },               // 12
+    { 0, GIE::StringListArgumentEnd, nullptr, 14, 0, nullptr },              // 13
 
     // string: save, string-list: save last
-    { 0, GIE::StringArgument, 0, 18, 15, "domainName" },          // 14
-    { 0, GIE::StringListArgumentStart, 0, 16, 0, 0 },             // 15
-    { 0, GIE::StringListEntry, 0, 16, 17, "domainName" },         // 16
-    { 0, GIE::StringListArgumentEnd, 0, 18, 0, 0 },               // 17
+    { 0, GIE::StringArgument, nullptr, 18, 15, "domainName" },          // 14
+    { 0, GIE::StringListArgumentStart, nullptr, 16, 0, nullptr },             // 15
+    { 0, GIE::StringListEntry, nullptr, 16, 17, "domainName" },         // 16
+    { 0, GIE::StringListArgumentEnd, nullptr, 18, 0, nullptr },               // 17
 
-    { 0, GIE::TestEnd, 0, 18, 20, 0 },      // 18
-    { 0, GIE::Any, 0, 18, 0, 0 },          // 19
+    { 0, GIE::TestEnd, nullptr, 18, 20, nullptr },      // 18
+    { 0, GIE::Any, nullptr, 18, 0, nullptr },          // 19
 
     // block of commands, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, 0, 21, 19, 0 },                          // 20
+    { 0, GIE::BlockStart, nullptr, 21, 19, nullptr },                          // 20
     { 1, GIE::CommandStart, "vacation", 23, 21, "vacation" },      // 21
-    { 1, GIE::Any, 0, 23, 0, 0 },                                  // 22
-    { 0, GIE::BlockEnd, 0, 24, 22, 0 },                            // 23
+    { 1, GIE::Any, nullptr, 23, 0, nullptr },                                  // 22
+    { 0, GIE::BlockEnd, nullptr, 24, 22, nullptr },                            // 23
 
-    { -1, GIE::Any, 0, 24, 24, 0 }  // 24 end state
+    { -1, GIE::Any, nullptr, 24, 24, nullptr }  // 24 end state
 };
 static const unsigned int numDomainNodes = sizeof domainNodes / sizeof *domainNodes;
 
@@ -521,53 +521,53 @@ public:
 // if not allof (currentdate :value "ge" date "YYYY-MM-DD",
 //               currentfate :value "le" date "YYYY-MM-DD) { keep; stop; }
 static const GenericInformationExtractor::StateNode datesNodes[] = {
-    { 0, GIE::CommandStart, "if", 1, 0, 0 },            // 0
-    { 0, GIE::TestStart, "allof", 2, 0, 0 },            // 1
+    { 0, GIE::CommandStart, "if", 1, 0, nullptr },            // 0
+    { 0, GIE::TestStart, "allof", 2, 0, nullptr },            // 1
 
     // handle startDate and endDate in arbitrary order
-    { 0, GIE::TestListStart, 0, 3, 0, 0 },                       // 2
-    { 0, GIE::TestStart, "currentdate", 4, 3, 0 },                  // 3
-    { 0, GIE::TaggedArgument, "value", 5, 4, 0 },                   // 4
-    { 0, GIE::StringArgument, "ge", 6, 10, 0 },                     // 5
-    { 0, GIE::StringArgument, "date", 7, 8, 0 },                    // 6
-    { 0, GIE::StringArgument, 0, 15, 0, "startDate" },              // 7
-    { 0, GIE::StringArgument, "iso8601", 9, 0, 0 },                 // 8
-    { 0, GIE::StringArgument, 0, 15, 0, "startDateTime" },          // 9
-    { 0, GIE::StringArgument, "le", 11, 0, 0 },                     // 10
-    { 0, GIE::StringArgument, "date", 12, 13, 0 },                  // 11
-    { 0, GIE::StringArgument, 0, 15, 0, "endDate" },                // 12
-    { 0, GIE::StringArgument, "iso8601", 14, 0, 0 },                // 13
-    { 0, GIE::StringArgument, 0, 15, 0, "endDateTime" },            // 14
-    { 0, GIE::TestEnd, 0, 16, 0, 0 },                            // 15
+    { 0, GIE::TestListStart, nullptr, 3, 0, nullptr },                       // 2
+    { 0, GIE::TestStart, "currentdate", 4, 3, nullptr },                  // 3
+    { 0, GIE::TaggedArgument, "value", 5, 4, nullptr },                   // 4
+    { 0, GIE::StringArgument, "ge", 6, 10, nullptr },                     // 5
+    { 0, GIE::StringArgument, "date", 7, 8, nullptr },                    // 6
+    { 0, GIE::StringArgument, nullptr, 15, 0, "startDate" },              // 7
+    { 0, GIE::StringArgument, "iso8601", 9, 0, nullptr },                 // 8
+    { 0, GIE::StringArgument, nullptr, 15, 0, "startDateTime" },          // 9
+    { 0, GIE::StringArgument, "le", 11, 0, nullptr },                     // 10
+    { 0, GIE::StringArgument, "date", 12, 13, nullptr },                  // 11
+    { 0, GIE::StringArgument, nullptr, 15, 0, "endDate" },                // 12
+    { 0, GIE::StringArgument, "iso8601", 14, 0, nullptr },                // 13
+    { 0, GIE::StringArgument, nullptr, 15, 0, "endDateTime" },            // 14
+    { 0, GIE::TestEnd, nullptr, 16, 0, nullptr },                            // 15
 
-    { 0, GIE::TestStart, "currentdate", 17, 16, 0 },                // 16
-    { 0, GIE::TaggedArgument, "value", 18, 17, 0 },                   // 17
-    { 0, GIE::StringArgument, "le", 19, 23, 0 },                      // 18
-    { 0, GIE::StringArgument, "date", 20, 21, 0 },                    // 19
-    { 0, GIE::StringArgument, 0, 28, 0, "endDate" },                  // 20
-    { 0, GIE::StringArgument, "iso8601", 22, 0, 0 },                  // 21
-    { 0, GIE::StringArgument, 0, 28, 0, "endDateTime" },              // 22
-    { 0, GIE::StringArgument, "ge", 24, 0, 0 },                       // 23
-    { 0, GIE::StringArgument, "date", 25, 26, 0 },                    // 24
-    { 0, GIE::StringArgument, 0, 28, 0, "startDate" },                // 25
-    { 0, GIE::StringArgument, "iso8601", 27, 0, 0 },                  // 26
-    { 0, GIE::StringArgument, 0, 28, 0, "startDateTime" },            // 27
-    { 0, GIE::TestEnd, 0, 32, 0, 0 },                              // 28
-    { 0, GIE::TestStart, 0, 31, 30, 0 },                // 29
-    { -1, GIE::Any, 0, 32, 0, 0 },                               // 30
-    { 0, GIE::TestEnd, 0, 32, 30, 0 },                // 31
-    { 0, GIE::TestListEnd, 0, 33, 29, 0 },                        // 32
+    { 0, GIE::TestStart, "currentdate", 17, 16, nullptr },                // 16
+    { 0, GIE::TaggedArgument, "value", 18, 17, nullptr },                   // 17
+    { 0, GIE::StringArgument, "le", 19, 23, nullptr },                      // 18
+    { 0, GIE::StringArgument, "date", 20, 21, nullptr },                    // 19
+    { 0, GIE::StringArgument, nullptr, 28, 0, "endDate" },                  // 20
+    { 0, GIE::StringArgument, "iso8601", 22, 0, nullptr },                  // 21
+    { 0, GIE::StringArgument, nullptr, 28, 0, "endDateTime" },              // 22
+    { 0, GIE::StringArgument, "ge", 24, 0, nullptr },                       // 23
+    { 0, GIE::StringArgument, "date", 25, 26, nullptr },                    // 24
+    { 0, GIE::StringArgument, nullptr, 28, 0, "startDate" },                // 25
+    { 0, GIE::StringArgument, "iso8601", 27, 0, nullptr },                  // 26
+    { 0, GIE::StringArgument, nullptr, 28, 0, "startDateTime" },            // 27
+    { 0, GIE::TestEnd, nullptr, 32, 0, nullptr },                              // 28
+    { 0, GIE::TestStart, nullptr, 31, 30, nullptr },                // 29
+    { -1, GIE::Any, nullptr, 32, 0, nullptr },                               // 30
+    { 0, GIE::TestEnd, nullptr, 32, 30, nullptr },                // 31
+    { 0, GIE::TestListEnd, nullptr, 33, 29, nullptr },                        // 32
 
-    { 0, GIE::TestEnd, 0, 34, 0, 0 },                   // 33
+    { 0, GIE::TestEnd, nullptr, 34, 0, nullptr },                   // 33
 
     // block of commands, find "stop", take nested if's into account:
-    { 0, GIE::BlockStart, 0, 36, 33, 0 },                   // 34
-    { -1, GIE::Any, 0, 36, 0, 0 },                         // 35
+    { 0, GIE::BlockStart, nullptr, 36, 33, nullptr },                   // 34
+    { -1, GIE::Any, nullptr, 36, 0, nullptr },                         // 35
     { 1, GIE::CommandStart, "vacation", 38, 35, "vacation" },      // 36
-    { -1, GIE::Any, 0, 38, 0, 0 },                         // 37
-    { 0, GIE::BlockEnd, 0, 39, 37, 0 },                     // 38
+    { -1, GIE::Any, nullptr, 38, 0, nullptr },                         // 37
+    { 0, GIE::BlockEnd, nullptr, 39, 37, nullptr },                     // 38
 
-    { -1, GIE::Any, 0, 39, 39, 0 }                      // 39 end state
+    { -1, GIE::Any, nullptr, 39, 39, nullptr }                      // 39 end state
 };
 
 static const unsigned int numDatesNodes = sizeof datesNodes / sizeof *datesNodes;
@@ -642,7 +642,7 @@ class VacationDataExtractor : public KSieve::ScriptBuilder
     };
 public:
     VacationDataExtractor();
-    virtual ~VacationDataExtractor();
+    ~VacationDataExtractor() override;
 
     bool commandFound() const
     {
@@ -772,7 +772,7 @@ class RequireExtractor : public KSieve::ScriptBuilder
     };
 public:
     RequireExtractor();
-    virtual ~RequireExtractor();
+    ~RequireExtractor() override;
 
     bool commandFound() const
     {
