@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -43,7 +43,7 @@ static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
 
 static inline QString stringReplace(QString s)
 {
-    s = s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
+    s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
     return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
 }
 
@@ -63,10 +63,9 @@ QString KSieveUi::VacationUtils::mailAction(KSieveUi::VacationUtils::MailAction
         return i18n("Redirect to");
     case CopyTo:
         return i18n("Copy to");
-    default:
-        qCWarning(LIBKSIEVE_LOG) << "Unknown mail action" << action;
-        return i18n("Unknown action");
     }
+    Q_UNREACHABLE();
+    return {};
 }
 
 KSieveUi::VacationUtils::MailAction KSieveUi::VacationUtils::defaultMailAction()
@@ -290,7 +289,7 @@ QString KSieveUi::VacationUtils::composeScript(const Vacation &vacation)
             sl.push_back(QLatin1Char('"') + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\"")) + QLatin1Char('"'));
             aliases.push_back((*it).asString());
         }
-        addressesArgument += sl.join(QStringLiteral(", ")) + QStringLiteral(" ] ");
+        addressesArgument += sl.join(QLatin1String(", ")) + QStringLiteral(" ] ");
     }
 
     QString sVacation(QStringLiteral("vacation "));
@@ -314,11 +313,11 @@ QString KSieveUi::VacationUtils::composeScript(const Vacation &vacation)
         sVacation += QStringLiteral("\ndiscard;");
         break;
     case VacationUtils::Sendto:
-        sVacation += QStringLiteral("\nredirect \"") + vacation.mailActionRecipient + QStringLiteral("\";");
+        sVacation += QLatin1String("\nredirect \"") + vacation.mailActionRecipient + QLatin1String("\";");
         break;
     case VacationUtils::CopyTo:
         require << QStringLiteral("copy");
-        sVacation += QStringLiteral("\nredirect :copy \"") + vacation.mailActionRecipient + QStringLiteral("\";");
+        sVacation += QLatin1String("\nredirect :copy \"") + vacation.mailActionRecipient + QLatin1String("\";");
         break;
     }
 
@@ -386,11 +385,11 @@ QString KSieveUi::VacationUtils::mergeRequireLine(const QString &script, const Q
 
     const int requirementscount = requirements.count();
     if (requirementscount > 1) {
-        QStringList req = requirements.toList();
+        QStringList req = requirements.values();
         req.sort();
         lines.insert(insert, QStringLiteral("require [\"%1\"];").arg(req.join(QStringLiteral("\", \""))));
     } else if (requirementscount == 1) {
-        lines.insert(insert, QStringLiteral("require \"%1\";").arg(requirements.toList().at(0)));
+        lines.insert(insert, QStringLiteral("require \"%1\";").arg(requirements.values().at(0)));
     }
 
     return lines.join(QLatin1Char('\n'));
